@@ -23,10 +23,10 @@ rownames(mm) <- c("Kolmogorov-Smirnov statistic", "Cramer-von Mises statistic",
                   "Anderson-Darling statistic", "Aikake's Information Criterion", "Bayesian Information Criterion")
 
 
-cdfcomp(flist, do.points=FALSE, leg=dlist, addlegend = FALSE, lwd=1.5, main="Emp./theo. CDFs - ecotoxicology")
+cdfcomp(flist, do.points=FALSE, leg=dlist, addlegend = FALSE, fitlwd=1.5, main="Emp./theo. CDFs - ecotoxicology")
 legend("topleft", col=c("red", "green", "blue"), leg=dlist, lty=1:3, lwd=2, bty="n")
 
 #log scale
 par(mar=c(4,4,2,1))
-cdfcomp(flist, do.points=FALSE, leg=dlist, xlogscale = TRUE, addlegend = FALSE, lwd=1.5, main="Emp./theo. CDFs - ecotoxicology")
+cdfcomp(flist, do.points=FALSE, leg=dlist, xlogscale = TRUE, addlegend = FALSE, fitlwd=1.5, main="Emp./theo. CDFs - ecotoxicology")
 legend("topleft", col=c("red", "green", "blue"), leg=dlist, lty=1:3, lwd=2, bty="n")
